@@ -50,6 +50,8 @@ class LocalRegressor(LocalModel):
         target: str,
         excluded_columns: Optional[List[str]] = None,
         *,
+        # Regression specific fit parameters
+        sample_weight: Optional[str] = None,
         order_by: Optional[str] = None,
         partition_by: Optional[str] = None,
         no_mixing: Optional[List[str]] = None,
@@ -82,6 +84,7 @@ class LocalRegressor(LocalModel):
             no_mixing_columns=no_mixing or UNSET,
             partition_column=partition_by or UNSET,
             order_by_column=order_by or UNSET,
+            weight_column=sample_weight or UNSET,
             model_types=self._initial_config.model_types or UNSET,
         )
 
