@@ -129,6 +129,10 @@ from .set_time_index_step import SetTimeIndexStep
 from .set_time_index_step_step_type import SetTimeIndexStepStepType
 from .simple_forecast import SimpleForecast
 from .simple_forecast_cadence import SimpleForecastCadence
+from .simplify_categories_definition import SimplifyCategoriesDefinition
+from .simplify_categories_rule import SimplifyCategoriesRule
+from .simplify_categories_step import SimplifyCategoriesStep
+from .simplify_categories_step_step_type import SimplifyCategoriesStepStepType
 from .split_column_step import SplitColumnStep
 from .split_column_step_step_type import SplitColumnStepStepType
 from .status import Status
